<?php

namespace DMG\Enhanced_Permalinks;

/**
 * Class Admin
 *
 * This class adds the Enhanced Permalinks Setting section
 *
 * @package DMG\Enhanced_Permalinks
 */
class Admin {

	/**
	 * Initial Construct
	 */
	public function __construct() {
		add_action( 'admin_init', [ __CLASS__, 'add_setting' ], 11 );
	}

	/**
	 * Add options to the Writing Settings page
	 */
	public static function add_setting() {

		/**
		 * Filter to choose a native WordPress page to put the Enhanced Permalinks
		 * settings section.
		 *
		 * Other examples include `reading`, `discussion`, or `media`.
		 *
		 * @param string $section The name of the settings sections to add the field to.
		 */
		$settings_page = apply_filters( 'dmg_permalink_stop_words_settings_page', 'writing' );

		// Add a new settings section for the new field
		add_settings_section(
			'enhanced_permalinks',
			'Enhanced Permalinks',
			[ __CLASS__, 'section_html' ],
			$settings_page
		);

		do_action( 'enhanced_permalinks_settings', $settings_page );
	}

	/**
	 * Enhanced Permalinks section HTML.
	 */
	public static function section_html() {
		printf(
			'<p>%s</p>',
			__( 'WordPress automatically builds a permalink slug based on the article title.<br/>Here, you can designate a list of common words to filter out of the permalink generation process to help keep your URLs short. You can also set a custom meta key to use to generate the permalink', 'enhanced-permalinks' )
		);
	}
}

new Admin();
