<?php

namespace DMG\Enhanced_Permalinks;

/**
 * Class API
 *
 * This class register a new REST API route that returns the filtered permalink
 *
 * @package DMG\Enhanced_Permalinks
 */
class API {

	/**
	 * Namespace within wp-json
	 *
	 * @var string
	 */
	const NAMESPACE = 'enhanced-permalinks';

	/**
	 * API constructor.
	 */
	public function __construct() {
		add_action( 'rest_api_init', array( __CLASS__, 'register_endpoints' ) );
	}

	/**
	 * Register rest routes within the namespace
	 *
	 * @example https://example.com/wp-json/enhanced-permalinks/generate/
	 *
	 */
	public static function register_endpoints() {

		// POST route for newsletter signup
		register_rest_route(
			self::NAMESPACE,
			'/generate/',
			array(
				'methods'             => [ 'POST', 'GET' ],
				'callback'            => array( __CLASS__, 'callback' ),
				'permission_callback' => [ __CLASS__, 'permissions_check' ],
			)
		);
	}

	/**
	 * Process the request and return the enhanced permalink
	 *
	 * @param \WP_REST_Request $request WP JSON Request object
	 *
	 * @return array The response
	 */
	public static function callback( $request ) {

		// Get parameters
		$params = $request->get_params();

		// Retrieve the Enhanced Permalink
		$enhanced_permalink = \DMG\Enhanced_Permalinks\Filters::return_the_slug( $params['post_title'], $params['data'] );

		$response = new \WP_REST_Response( [ 'success' => true, 'message' => $enhanced_permalink ], 200 );

		return $response;
	}

	/**
	 * Handle permissions
	 *
	 * @return bool
	 */
	public static function permissions_check() {
		return current_user_can( apply_filters( 'enhanced-permalinks_rest_api_cap', 'edit_posts' ) );
	}
}

new API();
