<?php

namespace DMG\Enhanced_Permalinks;

/**
 * Class Custom_Source
 *
 * Use a custom meta when generating the permalink
 *
 */
class Custom_Source {

	/**
	 * Option name
	 *
	 * @var string
	 */
	CONST OPTION_NAME = 'enhanced_permalinks_custom_meta';

	/**
	 * Initial load.
	 */
	public function __construct() {
		add_action( 'enhanced_permalinks_settings', [ __CLASS__, 'register_settings' ], 11 );
		add_filter( 'enhanced_permalinks_source', [ __CLASS__, 'filter_permalink_source' ], 10, 2 );
		add_action( 'enqueue_block_editor_assets', [ __CLASS__, 'add_inline_js' ], 11 );
	}

	/**
	 * Filter for the permalink source
	 *
	 * @param $source
	 * @param array $postarr
	 *
	 * @return mixed
	 */
	public static function filter_permalink_source( $source, $postarr = [] ) {

		$custom_meta_key = get_option( self::OPTION_NAME );

		if ( ! empty( $custom_meta_key ) && isset( $postarr[ $custom_meta_key ] ) & ! empty( $postarr[ $custom_meta_key ] ) ) {
			$source = $postarr[ $custom_meta_key ];
		}

		return strtolower( $source );
	}

	/**
	 * Register Settings for the module
	 *
	 * @param $settings_page
	 */
	public static function register_settings( $settings_page ) {
		// Add the settings field to the "optional" Custom Meta section on Permalink Settings
		add_settings_field(
			self::OPTION_NAME,
			sprintf(
				'<label for="%s">%s</label>',
				esc_attr( self::OPTION_NAME ),
				__( 'Custom Meta Key', 'permalink_stop_words' )
			),
			[ __CLASS__, 'setting_input_field_html' ],
			$settings_page,
			'enhanced_permalinks'
		);

		// Register a general setting
		register_setting(
			$settings_page,
			self::OPTION_NAME,
			'sanitize_text_field'
		);
	}

	/**
	 * Outputs the settings input field HTML.
	 */
	public static function setting_input_field_html() {
		printf(
			'<input id="%s" name="%s" value="%s" />
				<small class="admin-note">Define the custom meta key to use when generating the permalink. By default the post title will be userd.</small>',
			esc_attr( self::OPTION_NAME ),
			esc_attr( self::OPTION_NAME ),
			esc_textarea( get_option( self::OPTION_NAME ) )
		);
	}

	/**
	 * inline vars for the enhanced-permalinks JS
	 */
	public static function add_inline_js() {

		$params = array(
			'customMeta' => get_option( self::OPTION_NAME ),
		);

		wp_add_inline_script(
			'enhanced-permalinks',
			sprintf( 'var enhancedPermalinksParams = %s', wp_json_encode( $params ) ),
			'before'
		);
	}
}

new Custom_Source();
