/**
 * WordPress dependencies
 */
import apiFetch from '@wordpress/api-fetch';
import {compose} from "@wordpress/compose";
import {dispatch, select, subscribe, withSelect} from '@wordpress/data';
import {registerPlugin} from "@wordpress/plugins";
import {debounce} from 'lodash';

const enhancedPermalinks = ({postMetaKey}) => {

    const postMeta = document.getElementById(postMetaKey);

    setPermalink(postMeta);

    // Set the permalink on custom meta blur
    if ( postMeta ) {
        postMeta.addEventListener('blur', () => {
            setPermalink(postMeta);
            postMeta.removeEventListener('blur', this);
        });
    }

    // Just in case something is missing make sure the permalink is updated on post save
    subscribe(debounce(() => {
        const isSavingPost = select('core/editor').isSavingPost();
        const isAutosavingPost = select('core/editor').isAutosavingPost();

        if (!isAutosavingPost && isSavingPost) {
            setPermalink(postMeta);
        }
    }, 1000));

    return false;
}

const setPermalink = (postMeta) => {

    let postStatus = select('core/editor').getCurrentPostAttribute('status');

    // Update the permalink only if the post is not published
    if (postStatus && postStatus != 'publish') {
        let currentPostSlug = select('core/editor').getEditedPostAttribute('slug');

        apiFetch({
            path: 'enhanced-permalinks/generate',
            method: 'POST',
            data: {
                'post_title': select('core/editor').getEditedPostAttribute('title'),
                'data': {
                    [postMeta?.id] : postMeta?.value
                }
            },
        }).then(response => {
            return response;
        }).catch(error => {
            return error;
        }).then(response => {
            dispatch('core/editor').editPost({
                slug: response?.message
            });
        });
    }

}

const Init = compose(
    withSelect( (select) => {
        return {
            postMetaKey: enhancedPermalinksParams?.customMeta
        };
    } )
)(enhancedPermalinks);

registerPlugin('enhanced-permalinks', {render: Init});
